@@ -30,7 +30,9 @@ GA <-function (mu.link ="log", sigma.link="log")
         sigma.initial = expression({sigma <- rep(1,length(y))}) ,
              mu.valid = function(mu) all(mu > 0) , 
           sigma.valid = function(sigma)  all(sigma > 0), 
-              y.valid = function(y)  all(y > 0)
+              y.valid = function(y)  all(y > 0),
+                 mean = function(mu, sigma) mu,
+             variance = function(mu, sigma) sigma^2 * mu^2
           ),
                 class = c("gamlss.family","family"))
 }
