@@ -15,9 +15,10 @@ dWARING<-function (x, mu=2, sigma=2, log = FALSE)
       x <- rep(x, length = ly)      
   sigma <- rep(sigma, length = ly)
      mu <- rep(mu, length = ly)   
-      b <- 1+(1/sigma)
-      n <- mu*(b-1)
-     fx <- lbeta(n+x, b+1)-lbeta(n,b)
+      #b <- 1+(1/sigma)
+      #n <- mu*(b-1)
+     #fx <- lbeta(n+x, b+1)-lbeta(n,b)
+     fx <- lbeta(x+(mu/sigma), (1/sigma)+2)-lbeta(mu/sigma,(1/sigma+1))
      fx <- if(log) fx else exp(fx) 
      fx
 }
@@ -26,22 +27,23 @@ dWARING<-function (x, mu=2, sigma=2, log = FALSE)
 #Cumulative density function
 pWARING<-function (q,  mu=2, sigma=2,  lower.tail = TRUE, log.p = FALSE)
 {
-    if (any(mu < 0))
-        stop(paste("mu must be > 0", "\n", ""))
-    if (any(sigma < 0))
-    	stop(paste("sigma must be > 0", "\n", ""))
-    if (any(q < 0))
-        stop(paste("q must be >=0", "\n", ""))
+    if (any(mu < 0)) stop(paste("mu must be > 0", "\n", ""))
+    if (any(sigma < 0)) stop(paste("sigma must be > 0", "\n", ""))
+    if (any(q < 0)) stop(paste("q must be >=0", "\n", ""))
      ly <- max(length(q), length(mu), length(sigma))
       q <- rep(q, length = ly)
+      p <- rep(0, length = ly)
      mu <- rep(mu, length = ly)
   sigma <- rep(sigma, length = ly)
     #s1<- seq(0, max(q))
-    #cdf<- cumsum(dWAR(s1, mu=mu, sigma=sigma))
+    #cdf<- cumsum(dWARING(s1, mu=mu, sigma=sigma))
     #s2<-match(q,s1,nomatch=0)
     #cdf<- cdf[s2]
-    cdf <- 1- ((gamma((1+mu+sigma)/sigma)*gamma(1+(mu/sigma)+q))/
-          (gamma(mu/sigma)*gamma(2+((1+mu)/sigma)+q)))
+     fn <- function(q, mu, sigma) sum(dWARING(0:q, mu=mu, sigma=sigma))
+   Vcdf <- Vectorize(fn)
+    cdf <- Vcdf(q=q, mu=mu, sigma=sigma)
+    # cdf <- 1- ((gamma((1+mu+sigma)/sigma)*gamma(1+(mu/sigma)+q))/
+    #       (gamma(mu/sigma)*gamma(2+((1+mu)/sigma)+q)))
     if (lower.tail == TRUE) 
         cdf <- cdf
     else cdf = 1 - cdf
@@ -50,8 +52,7 @@ pWARING<-function (q,  mu=2, sigma=2,  lower.tail = TRUE, log.p = FALSE)
 }
 
 #Quantile Function
-qWARING<-
-function (p,  mu=2, sigma=2, lower.tail = TRUE, log.p = FALSE, max.value = 10000)
+qWARING<- function (p,  mu=2, sigma=2, lower.tail = TRUE, log.p = FALSE, max.value = 10000)
 {
     if (any(mu < 0))
         stop(paste("mu must be > 0", "\n", ""))
@@ -62,14 +63,14 @@ function (p,  mu=2, sigma=2, lower.tail = TRUE, log.p = FALSE, max.value = 10000
 if (lower.tail) p <- p
 else p <- 1 - p
     ly <- max(length(p), length(mu), length(sigma))
-    p <- rep(p, length = ly)
-    QQQ <- rep(0, length = ly)
+     p <- rep(p, length = ly)
+   QQQ <- rep(0, length = ly)
     mu <- rep(mu, length = ly)
-    sigma <- rep(sigma, length = ly)
-    for (i in seq(along = p)) {
+ sigma <- rep(sigma, length = ly)
+for (i in seq(along = p)) {
         cumpro <- 0
         if (p[i] + 1e-09 >= 1)
-            QQQ[i] <- Inf
+            QQQ[i] <- Inf 
         else {
             for (j in seq(from = 0, to = max.value)) {
                 cumpro <- pWARING(j, mu=mu[i], sigma=sigma[i])
@@ -156,6 +157,9 @@ WARING<-function (mu.link = "log", sigma.link = "log")
         sigma.initial = expression(sigma <- rep(1,length(y))), 
         mu.valid = function(mu) all(mu > 0),
         sigma.valid = function(sigma) all(sigma > 0), 
-        y.valid = function(y) all(y >= 0)), 
+        y.valid = function(y) all(y >= 0),
+		       mean = function(mu, sigma) mu,
+		   variance = function(mu, sigma) ifelse(sigma < 1, mu * (mu + 1) * (1 + sigma) / (1 - sigma), Inf)
+		  ), 
         class = c("gamlss.family", "family"))
 }
\ No newline at end of file
